

# Now-I-Can-Sleep (unstable)

A minimalist automated documentation generation tool for a GitHub repository.


## Usage

1. Install via pip:

    ```sh
    pip install nics
    ```

2. Navigate to your project root directory
3. Run:

    ```sh
    nics start
    ```
4. Follow the wizard, and you all set!